==> react-app-logic-12.1.0.tgz: package/src/wallet/providers/OnomyDashboardProvider.tsx <==
import React, { createContext, useContext, useMemo } from 'react';
import { DetailedFungibleAssetBalance, OnomyHubConstants } from '@onomy/hub';
import {
  serializeAsset,
  useDelegations,
  useDetailedBalance,
  useDetailedBalances,
  useFiatTotal,
  useHoldings,
} from '@onomy/react-hub';
import { useAsyncStatuses } from '@onomy/react-utils';
import BigNumber from 'bignumber.js';
import { PlaceholderLoadingIndicator } from '../../components/PlaceholderLoadingIndicator';
import { PlaceholderErrorDisplay } from '../../components/PlaceholderErrorDisplay';
import { useOnexDayTradeFrame } from '../../exchange/TheGraph/useOnexDayTradeFrame';
import { useOnexBurned, useOnexMyDrops } from '../../exchange/hooks';
import { useOnomyApp } from './OnomyApp';

function useOnomyDashboardState() {
  const {
    onomyNomAsset,
    onexNomAsset,
    onexEthAsset,
    onexUsdtAsset,
    loadingStatus: appLoadingStatus,
  } = useOnomyApp();
  const holdings = useHoldings();
  const [myLiquidity, myLiquidityStatus] = useOnexMyDrops();
  const [delegations, delegationsStatus] = useDelegations();
  const oneNomFixed = useMemo(
    () => new BigNumber('1').shiftedBy(onomyNomAsset.meta.decimalPlaces).toFixed(0),
    [onomyNomAsset.meta.decimalPlaces]
  );
  const [oneNomCoin] = useDetailedBalance(onomyNomAsset, oneNomFixed);

  const { principalTotalFiat, rewardTotalFiat, liquidityTotalFiat } = useMemo(() => {
    return myLiquidity.reduce(
      (res, item) => {
        res.principalTotalFiat += item.fiatPrincipal;
        res.rewardTotalFiat += item.fiatReward;
        res.liquidityTotalFiat += item.fiatTotal;
        return res;
      },
      {
        principalTotalFiat: 0,
        rewardTotalFiat: 0,
        liquidityTotalFiat: 0,
      }
    );
  }, [myLiquidity]);

  const onexBalancesRaw = useMemo(
    () => holdings.balances.filter(x => x.asset.chain.name === OnomyHubConstants.ONEX_CHAIN_ID),
    [holdings.balances]
  );

  const mainBalancesRaw = useMemo(
    () => holdings.balances.filter(x => x.asset.chain.name !== OnomyHubConstants.ONEX_CHAIN_ID),
    [holdings.balances]
  );

  const [onexBalances, onexBalancesStatus] = useDetailedBalances(onexBalancesRaw);
  const [mainBalances, mainBalancesStatus] = useDetailedBalances(mainBalancesRaw);

  const onexBalancesTotalFiat = useFiatTotal(onexBalances);
  const mainBalancesTotalFiat = useFiatTotal(mainBalances);
  const mainGrandTotalFiat =
    holdings.stakedTotalFiat + holdings.rewardTotalFiat + mainBalancesTotalFiat;
  const onexGrandTotalFiat = onexBalancesTotalFiat + liquidityTotalFiat;
  const grandTotalFiat = mainGrandTotalFiat + onexGrandTotalFiat;

  const [nomUsdtDay, nomUsdtDayStatus] = useOnexDayTradeFrame({
    baseAsset: onexNomAsset,
    quoteAsset: onexUsdtAsset,
  });

  const [nomEthDay, nomUsdtEthStatus] = useOnexDayTradeFrame({
    baseAsset: onexNomAsset,
    quoteAsset: onexEthAsset,
  });

  const [onexNomBurned, onexNomBurnedStatus] = useOnexBurned();

  const loadingStatus = useAsyncStatuses([
    appLoadingStatus,
    holdings.loadingStatus,
    nomUsdtDayStatus,
    nomUsdtEthStatus,
    myLiquidityStatus,
    delegationsStatus,

    onexBalancesStatus,
    mainBalancesStatus,
    onexNomBurnedStatus,
  ]);

  return {
    holdings,
    myLiquidity,
    delegations,

    nomUsdtDay,
    nomEthDay,
    onexNomBurned,

    onexBalances,
    mainBalances,

    oneNomCoin,

    principalTotalFiat,
    rewardTotalFiat,
    liquidityTotalFiat,

    onexBalancesTotalFiat,
    mainBalancesTotalFiat,
    mainGrandTotalFiat,
    onexGrandTotalFiat,
    grandTotalFiat,

    loadingStatus,
  };
}

export type OnomyDashboardContextType = ReturnType<typeof useOnomyDashboardState>;

const OnomyDashboardContext = createContext<OnomyDashboardContextType>(null as any);

export function useOnomyDashboard() {
  const state = useContext(OnomyDashboardContext);
  if (!state) throw new Error('OnomyDashboardContext missing');
  return state;
}

// eslint-disable-next-line @typescript-eslint/naming-convention
function DEFAULT_LOADING_RENDER_FN() {
  return <PlaceholderLoadingIndicator text="Loading dashboard" />;
}
// eslint-disable-next-line @typescript-eslint/naming-convention
function DEFAULT_ERROR_RENDER_FN(error: any) {
  return <PlaceholderErrorDisplay error={error} />;
}

export function OnomyDashboardProvider({
  children,
  renderLoading = DEFAULT_LOADING_RENDER_FN,
  renderError = DEFAULT_ERROR_RENDER_FN,
}: {
  children: JSX.Element | JSX.Element[];
  renderLoading?: typeof DEFAULT_LOADING_RENDER_FN;
  renderError?: typeof DEFAULT_ERROR_RENDER_FN;
}) {
  const state = useOnomyDashboardState();

  if (state.loadingStatus.pending) return renderLoading();
  if (state.loadingStatus.error) return renderError(state.loadingStatus.error);
  return <OnomyDashboardContext.Provider value={state}>{children}</OnomyDashboardContext.Provider>;
}

function useFindBalance(assetId: string, balances: DetailedFungibleAssetBalance[]) {
  return React.useMemo(
    () =>
      balances.find(a => serializeAsset(a.asset) === assetId) ?? OnomyHubConstants.UNKNOWN_BALANCE,
    [balances, assetId]
  );
}

export function useAvailableBalance(idOrAsset: string) {
  const { holdings } = useOnomyDashboard();
  const id = typeof idOrAsset === 'string' ? idOrAsset : serializeAsset(idOrAsset);
  return useFindBalance(id, holdings.balances);
}

export function useStakedBalance(idOrAsset: string) {
  const { holdings } = useOnomyDashboard();
  const id = typeof idOrAsset === 'string' ? idOrAsset : serializeAsset(idOrAsset);
  return useFindBalance(id, holdings.stakedBalances);
}

export function useRewardBalance(idOrAsset: string) {
  const { holdings } = useOnomyDashboard();
  const id = typeof idOrAsset === 'string' ? idOrAsset : serializeAsset(idOrAsset);
  return useFindBalance(id, holdings.rewardBalances);
}

export function useUnstakingBalance(idOrAsset: string) {
  const { holdings } = useOnomyDashboard();
  const id = typeof idOrAsset === 'string' ? idOrAsset : serializeAsset(idOrAsset);
  return useFindBalance(id, holdings.unbondingBalances);
}

export function useAssetDelegations(idOrAsset: string) {
  const { delegations } = useOnomyDashboard();
  const id = typeof idOrAsset === 'string' ? idOrAsset : serializeAsset(idOrAsset);

  return React.useMemo(
    () => delegations.filter(a => serializeAsset(a.delegated.asset) === id),
    [delegations, id]
  );
}

==> react-app-logic-13.0.2.tgz: package/src/wallet/providers/OnomyDashboardProvider.tsx <==
import React, { createContext, useContext, useMemo } from 'react';
import { DetailedFungibleAssetBalance, OnomyHubConstants } from '@onomy/hub';
import {
  serializeAsset,
  useDelegations,
  useDetailedBalance,
  useDetailedBalances,
  useFiatTotal,
  useHoldings,
} from '@onomy/react-hub';
import { useAsyncStatuses } from '@onomy/react-utils';
import BigNumber from 'bignumber.js';
import { PlaceholderErrorDisplay } from '../../components/PlaceholderErrorDisplay';
import { useOnexDayTradeFrame } from '../../exchange/TheGraph/useOnexDayTradeFrame';
import { useOnexBurned, useOnexMyDrops } from '../../exchange/hooks';
import { useOnomyApp } from './OnomyApp';
import { useVesting } from '../hooks/useVesting';

function useOnomyDashboardState() {
  const {
    onomyNomAsset,
    onexNomAsset,
    onexEthAsset,
    onexUsdtAsset,
    loadingStatus: appLoadingStatus,
  } = useOnomyApp();
  const holdings = useHoldings();
  const [vesting, vestingStatus] = useVesting();
  const [myLiquidity, myLiquidityStatus] = useOnexMyDrops();
  const [delegations, delegationsStatus] = useDelegations();
  const oneNomFixed = useMemo(
    () => new BigNumber('1').shiftedBy(onomyNomAsset.meta.decimalPlaces).toFixed(0),
    [onomyNomAsset.meta.decimalPlaces]
  );
  const [oneNomCoin] = useDetailedBalance(onomyNomAsset, oneNomFixed);

  const { principalTotalFiat, rewardTotalFiat, liquidityTotalFiat } = useMemo(() => {
    return myLiquidity.reduce(
      (res, item) => {
        res.principalTotalFiat += item.fiatPrincipal;
        res.rewardTotalFiat += item.fiatReward;
        res.liquidityTotalFiat += item.fiatTotal;
        return res;
      },
      {
        principalTotalFiat: 0,
        rewardTotalFiat: 0,
        liquidityTotalFiat: 0,
      }
    );
  }, [myLiquidity]);

  const onexBalancesRaw = useMemo(
    () => holdings.balances.filter(x => x.asset.chain.name === OnomyHubConstants.ONEX_CHAIN_ID),
    [holdings.balances]
  );

  const mainBalancesRaw = useMemo(
    () => holdings.balances.filter(x => x.asset.chain.name !== OnomyHubConstants.ONEX_CHAIN_ID),
    [holdings.balances]
  );

  const [onexBalances, onexBalancesStatus] = useDetailedBalances(onexBalancesRaw);
  const [mainBalances, mainBalancesStatus] = useDetailedBalances(mainBalancesRaw);

  const onexBalancesTotalFiat = useFiatTotal(onexBalances);
  const mainBalancesTotalFiat = useFiatTotal(mainBalances);
  const mainGrandTotalFiat =
    holdings.stakedTotalFiat + holdings.rewardTotalFiat + mainBalancesTotalFiat;
  const onexGrandTotalFiat = onexBalancesTotalFiat + liquidityTotalFiat;
  const grandTotalFiat = mainGrandTotalFiat + onexGrandTotalFiat;

  const [nomUsdtDay, nomUsdtDayStatus] = useOnexDayTradeFrame({
    baseAsset: onexNomAsset,
    quoteAsset: onexUsdtAsset,
  });

  const [nomEthDay, nomUsdtEthStatus] = useOnexDayTradeFrame({
    baseAsset: onexNomAsset,
    quoteAsset: onexEthAsset,
  });

  const [onexNomBurned, onexNomBurnedStatus] = useOnexBurned();

  const loadingStatus = useAsyncStatuses([
    appLoadingStatus,
    holdings.loadingStatus,
    vestingStatus,
    nomUsdtDayStatus,
    nomUsdtEthStatus,
    myLiquidityStatus,
    delegationsStatus,

    onexBalancesStatus,
    mainBalancesStatus,
    onexNomBurnedStatus,
  ]);

  return {
    holdings,
    vesting,
    myLiquidity,
    delegations,

    nomUsdtDay,
    nomEthDay,
    onexNomBurned,

    onexBalances,
    mainBalances,

    oneNomCoin,

    principalTotalFiat,
    rewardTotalFiat,
    liquidityTotalFiat,

    onexBalancesTotalFiat,
    mainBalancesTotalFiat,
    mainGrandTotalFiat,
    onexGrandTotalFiat,
    grandTotalFiat,

    loadingStatus,
  };
}

export type OnomyDashboardContextType = ReturnType<typeof useOnomyDashboardState>;

const OnomyDashboardContext = createContext<OnomyDashboardContextType>(null as any);

export function useOnomyDashboard() {
  const state = useContext(OnomyDashboardContext);
  if (!state) throw new Error('OnomyDashboardContext missing');
  return state;
}

// eslint-disable-next-line @typescript-eslint/naming-convention
function DEFAULT_ERROR_RENDER_FN(error: any) {
  return <PlaceholderErrorDisplay error={error} />;
}

export function OnomyDashboardProvider({
  children,
  renderLoading,
  renderError = DEFAULT_ERROR_RENDER_FN,
}: {
  children: JSX.Element | JSX.Element[];
  renderLoading?: () => JSX.Element | JSX.Element[] | null;
  renderError?: typeof DEFAULT_ERROR_RENDER_FN;
}) {
  const state = useOnomyDashboardState();

  if (state.loadingStatus.pending && renderLoading) return renderLoading();
  if (state.loadingStatus.error) return renderError(state.loadingStatus.error);
  return <OnomyDashboardContext.Provider value={state}>{children}</OnomyDashboardContext.Provider>;
}

function useFindBalance(assetId: string, balances: DetailedFungibleAssetBalance[]) {
  return React.useMemo(
    () =>
      balances.find(a => serializeAsset(a.asset) === assetId) ?? OnomyHubConstants.UNKNOWN_BALANCE,
    [balances, assetId]
  );
}

export function useAvailableBalance(idOrAsset: string) {
  const { holdings } = useOnomyDashboard();
  const id = typeof idOrAsset === 'string' ? idOrAsset : serializeAsset(idOrAsset);
  return useFindBalance(id, holdings.balances);
}

export function useStakedBalance(idOrAsset: string) {
  const { holdings } = useOnomyDashboard();
  const id = typeof idOrAsset === 'string' ? idOrAsset : serializeAsset(idOrAsset);
  return useFindBalance(id, holdings.stakedBalances);
}

export function useRewardBalance(idOrAsset: string) {
  const { holdings } = useOnomyDashboard();
  const id = typeof idOrAsset === 'string' ? idOrAsset : serializeAsset(idOrAsset);
  return useFindBalance(id, holdings.rewardBalances);
}

export function useUnstakingBalance(idOrAsset: string) {
  const { holdings } = useOnomyDashboard();
  const id = typeof idOrAsset === 'string' ? idOrAsset : serializeAsset(idOrAsset);
  return useFindBalance(id, holdings.unbondingBalances);
}

export function useAssetDelegations(idOrAsset: string) {
  const { delegations } = useOnomyDashboard();
  const id = typeof idOrAsset === 'string' ? idOrAsset : serializeAsset(idOrAsset);

  return React.useMemo(
    () => delegations.filter(a => serializeAsset(a.delegated.asset) === id),
    [delegations, id]
  );
}
